@@ -14,6 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.conformance.alignments.variants import state_equation_a_star, tweaked_state_equation_a_star, dijkstra_no_heuristics, \
-    dijkstra_less_memory, state_equation_less_memory
+import warnings
 
+warnings.warn("please use pm4py.algo.conformance.alignments.petri_net.variants instead")
+
+from pm4py.algo.conformance.alignments.petri_net.variants import *
