@@ -15,8 +15,21 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.algo.discovery.footprints.tree.variants import bottomup as bottomup_discovery
-from pm4py.objects.process_tree import bottomup as bottomup_util
-from pm4py.algo.discovery.footprints.outputs import Outputs
+from pm4py.objects.process_tree.utils import bottomup as bottomup_util
+from enum import Enum
+
+class Outputs(Enum):
+    DFG = "dfg"
+    SEQUENCE = "sequence"
+    PARALLEL = "parallel"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    ACTIVITIES = "activities"
+    SKIPPABLE = "skippable"
+    ACTIVITIES_ALWAYS_HAPPENING = "activities_always_happening"
+    MIN_TRACE_LENGTH = "min_trace_length"
+    TRACE = "trace"
+
 
 FP_DEV_COLOR = "red"
 FP_START_END_DEV_COLOR = "blue"
