@@ -16,11 +16,12 @@
 '''
 from pm4py.algo.filtering.common import filtering_constants
 from pm4py.util.constants import CASE_CONCEPT_NAME
-from pm4py.statistics.traces.pandas import case_statistics
-from pm4py.statistics.traces.pandas.case_statistics import get_variants_df
+from pm4py.statistics.traces.generic.pandas import case_statistics
+from pm4py.statistics.traces.generic.pandas.case_statistics import get_variants_df
 from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY, PARAMETER_CONSTANT_ACTIVITY_KEY
 from enum import Enum
 from pm4py.util import exec_utils
+from copy import copy
 
 
 class Parameters(Enum):
@@ -110,4 +111,6 @@ def apply(df, admitted_variants, parameters=None):
         ret = df[i1.isin(i2)]
     else:
         ret = df[~i1.isin(i2)]
+
+    ret.attrs = copy(df.attrs) if hasattr(df, 'attrs') else {}
     return ret
