@@ -16,7 +16,8 @@
 '''
 from pm4py.objects.log.util import insert_classifier, log, sampling, \
     sorting, index_attribute, get_class_representation, get_prefixes, \
-    get_log_encoded, interval_lifecycle, log_regex, basic_filter
+    get_log_encoded, interval_lifecycle, log_regex, basic_filter, \
+    filtering_utils, split_train_test, time_from_previous, xes
 import pkgutil
 
 if pkgutil.find_loader("pandas"):
