@@ -24,8 +24,20 @@ from pm4py.objects.dfg.utils import dfg_utils
 from pm4py.util import xes_constants as xes
 from pm4py.visualization.common.utils import *
 from pm4py.util import exec_utils
-from pm4py.visualization.dfg.parameters import Parameters
 from pm4py.statistics.sojourn_time.log import get as soj_time_get
+from enum import Enum
+from pm4py.util import constants
+
+
+class Parameters(Enum):
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+    FORMAT = "format"
+    MAX_NO_EDGES_IN_DIAGRAM = "maxNoOfEdgesInDiagram"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
+    START_TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_START_TIMESTAMP_KEY
+    FONT_SIZE = "font_size"
 
 
 def get_min_max_value(dfg):
@@ -114,7 +126,8 @@ def get_activities_color(activities_count):
 
 
 def graphviz_visualization(activities_count, dfg, image_format="png", measure="frequency",
-                           max_no_of_edges_in_diagram=170, start_activities=None, end_activities=None, soj_time=None):
+                           max_no_of_edges_in_diagram=100000, start_activities=None, end_activities=None, soj_time=None,
+                            font_size="12"):
     """
     Do GraphViz visualization of a DFG graph
 
@@ -190,10 +203,10 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     for act in activities_to_include:
         if "frequency" in measure and act in activities_count_int:
             viz.node(str(hash(act)), act + " (" + str(activities_count_int[act]) + ")", style='filled',
-                     fillcolor=activities_color[act])
+                     fillcolor=activities_color[act], fontsize=font_size)
             activities_map[act] = str(hash(act))
         else:
-            viz.node(str(hash(act)), act + " (" + human_readable_stat(soj_time[act]) + ")")
+            viz.node(str(hash(act)), act + " (" + human_readable_stat(soj_time[act]) + ")", fontsize=font_size)
             activities_map[act] = str(hash(act))
 
     # make edges addition always in the same order
@@ -205,7 +218,7 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
             label = str(dfg[edge])
         else:
             label = human_readable_stat(dfg[edge])
-        viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, penwidth=str(penwidth[edge]))
+        viz.edge(str(hash(edge[0])), str(hash(edge[1])), label=label, penwidth=str(penwidth[edge]), fontsize=font_size)
 
     start_activities_to_include = [act for act in start_activities if act in activities_map]
     end_activities_to_include = [act for act in end_activities if act in activities_map]
@@ -214,16 +227,15 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
         viz.node("@@startnode", "@@S", style='filled', shape='circle', fillcolor="#32CD32", fontcolor="#32CD32")
         for act in start_activities_to_include:
             label = str(start_activities[act]) if isinstance(start_activities, dict) else ""
-            viz.edge("@@startnode", activities_map[act], label=label)
+            viz.edge("@@startnode", activities_map[act], label=label, fontsize=font_size)
 
     if end_activities_to_include:
         viz.node("@@endnode", "@@E", style='filled', shape='circle', fillcolor="#FFA500", fontcolor="#FFA500")
         for act in end_activities_to_include:
             label = str(end_activities[act]) if isinstance(end_activities, dict) else ""
-            viz.edge(activities_map[act], "@@endnode", label=label)
+            viz.edge(activities_map[act], "@@endnode", label=label, fontsize=font_size)
 
     viz.attr(overlap='false')
-    viz.attr(fontsize='11')
 
     viz.format = image_format
 
@@ -236,9 +248,11 @@ def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
 
     activity_key = exec_utils.get_param_value(Parameters.ACTIVITY_KEY, parameters, xes.DEFAULT_NAME_KEY)
     image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
-    max_no_of_edges_in_diagram = exec_utils.get_param_value(Parameters.MAX_NO_EDGES_IN_DIAGRAM, parameters, 75)
+    max_no_of_edges_in_diagram = exec_utils.get_param_value(Parameters.MAX_NO_EDGES_IN_DIAGRAM, parameters, 100000)
     start_activities = exec_utils.get_param_value(Parameters.START_ACTIVITIES, parameters, [])
     end_activities = exec_utils.get_param_value(Parameters.END_ACTIVITIES, parameters, [])
+    font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 12)
+    font_size = str(font_size)
     activities = dfg_utils.get_activities_from_dfg(dfg)
 
     if activities_count is None:
@@ -255,4 +269,5 @@ def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
 
     return graphviz_visualization(activities_count, dfg, image_format=image_format, measure="frequency",
                                   max_no_of_edges_in_diagram=max_no_of_edges_in_diagram,
-                                  start_activities=start_activities, end_activities=end_activities, soj_time=soj_time)
+                                  start_activities=start_activities, end_activities=end_activities, soj_time=soj_time,
+                                  font_size=font_size)
